@@ -1,6 +1,6 @@
 package Reflex::Role::Streaming;
 BEGIN {
-  $Reflex::Role::Streaming::VERSION = '0.060';
+  $Reflex::Role::Streaming::VERSION = '0.070';
 }
 use Reflex::Role;
 
@@ -17,33 +17,51 @@ role {
 	my $h           = $p->handle();
 	my $cb_error    = $p->cb_error();
 	my $method_read = "_on_${h}_readable";
+	my $method_put  = $p->method_put();
+
+	my $method_writable = "_on_${h}_writable";
+	my $internal_flush  = "_do_${h}_flush";
+	my $internal_put    = "_do_${h}_put";
+	my $pause_writable  = "_pause_${h}_writable";
+	my $resume_writable = "_resume_${h}_writable";
 
 	with 'Reflex::Role::Collectible';
 
 	method_emit_and_stop $cb_error => "error";
 
 	with 'Reflex::Role::Reading' => {
-		handle    => $h,
-		cb_data   => $p->cb_data(),
-		cb_error  => $cb_error,
-		cb_closed => $p->cb_closed(),
+		handle      => $h,
+		cb_data     => $p->cb_data(),
+		cb_error    => $cb_error,
+		cb_closed   => $p->cb_closed(),
 		method_read => $method_read,
 	};
 
 	with 'Reflex::Role::Readable' => {
-		handle    => $h,
-		active    => 1,
-		cb_ready  => $method_read,
+		handle      => $h,
+		active      => 1,
+		cb_ready    => $method_read,
 	};
 
 	with 'Reflex::Role::Writing' => {
 		handle      => $h,
 		cb_error    => $cb_error,
-		method_put  => $p->method_put(),
+		method_put  => $internal_put,
+	};
+
+	method $method_writable => sub {
+		my ($self, $arg) = @_;
+
+		my $octets_left = $self->$internal_flush();
+		return if $octets_left;
+
+		$self->$pause_writable($arg);
 	};
 
 	with 'Reflex::Role::Writable' => {
-		handle  => $h,
+		handle      => $h,
+		cb_ready    => $method_writable,
+		method_pause => $pause_writable,
 	};
 
 	# Multiplex a single stop() to the sub-roles.
@@ -52,6 +70,13 @@ role {
 		$self->stop_handle_readable();
 		$self->stop_handle_writable();
 	};
+
+	method $method_put => sub {
+		my ($self, $arg) = @_;
+		my $flush_status = $self->$internal_put($arg);
+		return unless $flush_status;
+		$self->$resume_writable(), return if $flush_status == 1;
+	};
 };
 
 1;
@@ -64,7 +89,7 @@ Reflex::Role::Streaming - add streaming I/O behavior to a class
 
 =head1 VERSION
 
-version 0.060
+version 0.070
 
 =head1 SYNOPSIS
 
