@@ -1,17 +1,14 @@
 package Reflex::Role::Writing;
 BEGIN {
-  $Reflex::Role::Writing::VERSION = '0.060';
+  $Reflex::Role::Writing::VERSION = '0.070';
 }
 use Reflex::Role;
 
 attribute_parameter handle        => "handle";
 method_parameter    method_put    => qw( put handle _ );
-method_parameter    method_flush  => qw( on handle writable );
+method_parameter    method_flush  => qw( flush handle _ );
 callback_parameter  cb_error      => qw( on handle error );
 
-method_parameter    method_pause_writable   => qw( pause handle writable );
-method_parameter    method_resume_writable  => qw( resume handle writable );
-
 role {
 	my $p = shift;
 
@@ -27,9 +24,6 @@ role {
 		default => sub { my $x = ""; \$x },
 	);
 
-	my $resume_writable = "resume_${h}_writable";
-	my $pause_writable  = "pause_${h}_writable";
-
 	method $method_flush => sub {
 		my ($self, $arg) = @_;
 
@@ -52,9 +46,7 @@ role {
 		substr($$out_buffer, 0, $octet_count, "");
 
 		# Pause writes if it all was flushed.
-		return if length $$out_buffer;
-		$self->$pause_writable();
-		return;
+		return length $$out_buffer;
 	};
 
 	method $p->method_put() => sub {
@@ -67,7 +59,7 @@ role {
 		my $out_buffer = $self->out_buffer();
 		if (length $$out_buffer) {
 			$$out_buffer .= $_ foreach @chunks;
-			return length $$out_buffer;
+			return 2;
 		}
 
 		# Try to flush 'em all.
@@ -95,8 +87,7 @@ role {
 			$$out_buffer = substr($next, $octet_count);
 			$$out_buffer .= $_ foreach @chunks;
 
-			$self->$resume_writable();
-			return length $$out_buffer;
+			return 1;
 		}
 
 		# Flushed it all.  Yay!
@@ -110,46 +101,39 @@ __END__
 
 =head1 NAME
 
-Reflex::Role::Writing - add standard syswrite() behavior to a class
+Reflex::Role::Writing - add buffered non-blocking syswrite() to a class
 
 =head1 VERSION
 
-version 0.060
+version 0.070
 
 =head1 SYNOPSIS
 
 	package OutputStreaming;
 	use Reflex::Role;
 
-	attribute_parameter handle      => "handle";
-	callback_parameter  cb_error    => qw( on handle error );
-	method_parameter    method_put  => qw( put handle _ );
-	method_parameter    method_stop => qw( stop handle _ );
-
-	method_parameter    method_pause_writable  => qw( _pause handle writable );
-	method_parameter    method_resume_writable => qw( _resume handle writable );
-	method_parameter    method_flush           => qw( _flush handle writable );
+	attribute_parameter handle       => "handle";
+	callback_parameter  cb_error     => qw( on handle error );
+	method_parameter    method_put   => qw( put handle _ );
+	method_parameter    method_stop  => qw( stop handle _ );
+	method_parameter    method_flush => qw( _flush handle writable );
 
 	role {
 		my $p = shift;
 
-		my $h               = $p->handle();
-		my $cb_error        = $p->cb_error();
+		my $h         = $p->handle();
+		my $cb_error  = $p->cb_error();
 
 		with 'Reflex::Role::Writing' => {
-			handle                  => $h,
-			cb_error                => $p->cb_error(),
-			method_put              => $p->method_put(),
-			method_flush            => $p->method_flush(),
-			method_pause_writable   => $p->method_pause_writable(),
-			method_resume_writable  => $p->method_resume_writable(),
+			handle        => $h,
+			cb_error      => $p->cb_error(),
+			method_put    => $p->method_put(),
+			method_flush  => $p->method_flush(),
 		};
 
 		with 'Reflex::Role::Writable' => {
 			handle        => $h,
 			cb_ready      => $p->method_flush(),
-			method_pause  => $p->method_pause_writable(),
-			method_resume => $p->method_resume_writable(),
 		};
 
 =head1 DESCRIPTION
@@ -164,10 +148,7 @@ buffered syswrite() on a named "handle".  It has a single callback,
 "cb_error", that is invoked if syswrite() ever returns an error.  It
 defines a method, "method_put", that is used to write new data to the
 handle---or buffer data if it can't be written immediately.
-"method_flush" is defined to flush buffered data when possible.  The
-other methods, "method_pause_writable" and "method_resume_writable"
-aren't generated by this role.  Rather, this role calls them to
-disable and re-enable background writes as needed.
+"method_flush" is defined to flush buffered data when possible.
 
 Reflex::Role::Writable implements the other side of the
 Writable/Writing contract.  It wastches a "handle" and invokes
@@ -231,27 +212,41 @@ will be added to the buffer as well.
 The "method_put" implementation will call "method_resume_writable" to
 enable background flushing, as needed.
 
-The generated "method_put" will return the number of octets remaining
-in the buffer, or 0 if the buffer is empty.  It will return undef if
-syswrite() failed, and $! will be set to the reason for the failure.
+The generated "method_put" will return a numeric code representing the
+current state of the role's output buffer.  Undef if syswrite failed,
+after "cb_error" has been called.  It returns 0 if the buffer is still
+empty after the syswrite().  It returns 1 if the buffer begins to
+contain data, or 2 if the buffer already contained data and now holds
+more.
+
+The return code is intended to control Reflex::Role::Writable, via
+some glue code in the class or role that consumes both.  When
+"method_put" returns 1, the consumer should begin triggering
+"method_flush" calls on writability callbacks.  The consumer should
+stop writability callbacks when "method_flush" returns 0 (no more
+octets in the buffer).
 
 =head3 method_flush
 
 This role generates a method to flush data that had to be buffered by
-previous "method_put" calls.  This method will call
-"method_pause_writable" to disable background flushing if the buffer
-is fully flushed.
+previous "method_put" calls.  It's designed to be used with some kind
+of callback system, such as Reflex::Role::Writable's callbacks.
+
+The "method_flush" implementation returns undef on error.  It will
+return the number of octets remaining in the buffer, or zero if the
+buffer has been completely flushed.
+
+The "method_flush" return value may be used to disable writability
+watchers, such as the one provided by Reflex::Role::Writable.  See the
+source for Reflex::Role::Streaming for an up-to-date example.
 
 =head1 TODO
 
-This role should probably not be concerned with pausing and resuming
-writability watchers.  Rather, method_flush should return the state of
-the internal buffer so that the caller can do the right
-thing---whatever that may be.
+There's always something.
 
 =head1 EXAMPLES
 
-TODO - I'm sure there are some.
+Reflex::Role::Streaming is an up-to-date example.
 
 =head1 SEE ALSO
 
